@@ -7,8 +7,11 @@ import warnings
 
 
 def restart_runtime():
-    import os
-    os.kill(os.getpid(), 9)
+    if is_colab():
+        import os
+        os.kill(os.getpid(), 9)
+    else:
+        raise EnvironmentError('Restarting environment necessary..!')
 
 
 def is_colab():
@@ -86,10 +89,10 @@ def patch_uc(src: str = '/content/chromedriver_linux64.zip',
         warnings.warn(
             f"Cannot find the {PY_uc} module. "
             f"If you want to use undetected-chromedriver"
-            f"you can install it with 'pip install {PY_uc}'"
-            f"and then run in Python:"
-            f"from selenium_profiles.utils.colab_utils import patch_uc"
-            f"patch_uc()"
+            f"you can install it with 'pip install {PY_uc}'\n"
+            f"and then run in Python:\n"
+            f'from selenium_profiles.utils.colab_utils import patch_uc'
+            f'patch_uc()'
         )
         return
 
